@@ -15,7 +15,7 @@ require Exporter;
 # walkoptree comes from B.xs
 
 BEGIN {
-    $B::VERSION = '1.58';
+    $B::VERSION = '1.62';
     @B::EXPORT_OK = ();
 
     # Our BOOT code needs $VERSION set, and will append to @EXPORT_OK.
@@ -274,72 +274,6 @@ sub walksymtable {
     }
 }
 
-{
-    package B::Section;
-    my $output_fh;
-    my %sections;
-
-    sub new {
-	my ($class, $section, $symtable, $default) = @_;
-	$output_fh ||= FileHandle->new_tmpfile;
-	my $obj = bless [-1, $section, $symtable, $default], $class;
-	$sections{$section} = $obj;
-	return $obj;
-    }
-
-    sub get {
-	my ($class, $section) = @_;
-	return $sections{$section};
-    }
-
-    sub add {
-	my $section = shift;
-	while (defined($_ = shift)) {
-	    print $output_fh "$section->[1]\t$_\n";
-	    $section->[0]++;
-	}
-    }
-
-    sub index {
-	my $section = shift;
-	return $section->[0];
-    }
-
-    sub name {
-	my $section = shift;
-	return $section->[1];
-    }
-
-    sub symtable {
-	my $section = shift;
-	return $section->[2];
-    }
-
-    sub default {
-	my $section = shift;
-	return $section->[3];
-    }
-
-    sub output {
-	my ($section, $fh, $format) = @_;
-	my $name = $section->name;
-	my $sym = $section->symtable || {};
-	my $default = $section->default;
-
-	seek($output_fh, 0, 0);
-	while (<$output_fh>) {
-	    chomp;
-	    s/^(.*?)\t//;
-	    if ($1 eq $name) {
-		s{(s\\_[0-9a-f]+)} {
-		    exists($sym->{$1}) ? $sym->{$1} : $default;
-		}ge;
-		printf $fh $format, $_;
-	    }
-	}
-    }
-}
-
 1;
 
 __END__
