@@ -100,7 +100,7 @@ typedef struct yy_parser {
 
     YYSTYPE	nextval[5];	/* value of next token, if any */
     I32		nexttype[5];	/* type of next token */
-    I32		nexttoke;
+    U32		nexttoke;
 
     COP		*saved_curcop;	/* the previous PL_curcop */
     char	tokenbuf[256];
@@ -111,6 +111,7 @@ typedef struct yy_parser {
     PERL_BITFIELD16	in_pod:1;      /* lexer is within a =pod section */
     PERL_BITFIELD16	filtered:1;    /* source filters in evalbytes */
     PERL_BITFIELD16	saw_infix_sigil:1; /* saw & or * or % operator */
+    PERL_BITFIELD16	parsed_sub:1;  /* last thing parsed was a sub */
 } yy_parser;
 
 /* flags for lexer API */
@@ -148,11 +149,5 @@ enum {
 };
 
 /*
- * Local variables:
- * c-indentation-style: bsd
- * c-basic-offset: 4
- * indent-tabs-mode: nil
- * End:
- *
  * ex: set ts=8 sts=4 sw=4 et:
  */
